#-----------------------------------------------------------------------
# Canthology: software that makes it easy to create anthologies.
#
# Copyright (C) 2011 Ciaran McHale.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#----------------------------------------------------------------------

proc readFile {fileName} {
	if {[catch {
		set fd [open $fileName "r"]
		set contents [read $fd]
		close $fd
	} err]} {
		puts stderr $err
		exit 1
	}
	return $contents
}

proc writeFile {fileName contents} {
	if {[catch {
		set fd [open $fileName "w"]
		puts -nonewline $fd $contents
		close $fd
	} err]} {
		puts stderr $err
		exit 1
	}
}

proc processHtmlFile {fileName} {
	set contents [readFile $fileName]

	#--------
	# The entries in mapList do the following:
	# Lines 1 and 2: Remove empty last row in tables
	# Lines 3 and 4: Put some padding into cells in tables
	#
	# By the way, the following addition to mapList could be
	# used remove lines drawn above and below figures:
	#
	#	{<HR WIDTH="80%" SIZE=2>}		{} \
	#
	# However, the same effect is achieved (more elegantly) by
	# the following line in "hevea-fix.hva":
	#
	#	\renewcommand{\@figrule}{}
	#--------
	set mapList [list \
		{<TR><TD ALIGN=left NOWRAP></TD></TR>}	{} \
		{<TR><TD VALIGN=top ALIGN=left NOWRAP></TD></TR>} {} \
		{<TABLE BORDER=1 CELLSPACING=0 CELLPADDING=1>}	\
			{<TABLE BORDER=1 CELLSPACING=0 CELLPADDING=3>} \
	]
	set contents [string map $mapList $contents]

	# resync vim syntax highlightling "
	writeFile $fileName $contents
}

#--------
# Mainline
#--------
set prog [file tail $argv0]
foreach fileName $argv {
	#puts "$prog: processing $fileName..."
	processHtmlFile $fileName
}
